@@ -7,11 +7,11 @@ import piemap.cli as cli
 
 def test_main_ok_empty_array():
     job = ['[]']
-    assert cli.main(job) is None
+    assert cli.main(job) == 0
 
 
 def test_main_nok_wrong_type_intng():
     bad = 42
-    message = r"argument of type 'int' is not iterable"
+    message = r"'int' object is not iterable"
     with pytest.raises(TypeError, match=message):
-        cli.main(bad)
+        cli.main(bad)  # type: ignore
